/*
 * Image with rounded corners:
 * Place an image with rounded corners
 *
 * Get the bounding box of an image and create a clipping path as a rectangle
 * with the image size and with rounded corners. Fit the image into a box
 * with the position and size of the clipping path.
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 9
 * Required data: image file
 */
package com.pdflib.cookbook.pdflib.images;

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class image_rounded_corners
{
    public static void main (String argv[])
    {
        /* This is where the data files are. Adjust as necessary. */
        String searchpath = "../input";
        String outfile = "image_rounded_corners.pdf";
        String title = "Image with Rounded Corners";

        pdflib p = null;
        int exitcode = 0;
        String imagefile = "nesrin.jpg";
        int image, bbox;
        int radius = 50;      // radius of the circle for the rounded corners
        int x = 50, y = 300;  // lower left position of the image

        try {
            p = new pdflib();

            p.set_option("searchpath={" + searchpath + "}");

            /* This means we must check return values of load_image() etc. */
            p.set_option("errorpolicy=return");

            if (p.begin_document(outfile, "") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.set_info("Creator", "PDFlib Cookbook");
            p.set_info("Title", title);

            /* Load image */
            image = p.load_image("auto", imagefile, "");
            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            /* Start a A4 page */
            p.begin_page_ext(0, 0, "height=a4.height width=a4.width");

            /* Retrieve the image's bounding box as path object */
            bbox = (int) p.info_image(image, "boundingbox", 
                "boxsize {495 400} position center fitmethod=meet");

            p.save();
            /* Use the bounding box path as clipping path */
            p.draw_path(bbox, x, y, "round=" + radius + " clip close");

            /* Fit the image into a box with the size and start point (x,y) of the
             * clipping path. The image is placed in the center of the box using the
             * fit method "meet" which will scale the image proportionally so that
             * it completely covers the box.
             */
            p.fit_image(image, x, y, 
                "boxsize {495 400 } position center fitmethod=meet");

            /* Restore the previous graphics state (without clipping) and close image */
            p.restore();
            p.close_image(image);

            p.end_page_ext("");
            p.end_document("");

        } catch (PDFlibException e) {
            System.err.println("PDFlib exception occurred:");
            System.err.println("[" + e.get_errnum() + "] " + e.get_apiname() +
                                ": " + e.get_errmsg());
            exitcode = 1;
        } catch (Exception e) {
            System.err.println(e);
            exitcode = 1;
        } finally {
            if (p != null) {
                p.delete();
            }
            System.exit(exitcode);
        }
    }
}