/*
 * Images to PDF/A:
 * Convert grayscale, CMYK or RGB image files in TIFF or JPEG formats to 
 * PDF/A-2b, taking care of color space issues.
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 9
 * Required data: image files
 */
package com.pdflib.cookbook.pdflib.pdfa;

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class images_to_pdfa2b {
    public static void main(String argv[]) {
        /* This is where the data files are. Adjust as necessary. */
        String searchpath = "../input";
        String outfile = "images_to_pdfa2b.pdf";
        String title = "Images to PDF/A";

        pdflib p = null;
        String imagefileRGB = "nesrin.jpg";
        String imagefileCMYK = "kraxi_header.tif";
        String imagefileGray = "nesrin_gray.jpg";

        int exitcode = 0;
        int image, icc;

        try {
            p = new pdflib();

            p.set_option("searchpath={" + searchpath + "}");

            /* This means we must check return values of load_font() etc. */
            p.set_option("errorpolicy=return");

            /* Output all contents conforming to PDF/A-2b */
            if (p.begin_document(outfile, "pdfa=PDF/A-2b") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.set_info("Creator", "PDFlib Cookbook");
            p.set_info("Title", title);

            /*
             * Use sRGB as output intent since it allows the color spaces
             * ICC-based, grayscale, and RGB. CMYK images must be tagged with a
             * suitable CMYK ICC profile.
             */
            if (p.load_iccprofile("sRGB", "usage=outputintent") == -1){
                System.err.println("Error: " + p.get_errmsg() );
                System.err.println("See www.pdflib.com for output intent ICC profiles.");
                p.delete();
                System.exit(2);
            }

            /* Load an ICC profile for CMYK images */
            icc = p.load_iccprofile("ISOcoated_v2_eci.icc", "");
            if (icc == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.begin_page_ext(0, 0, "width=a4.width height=a4.height");

            /*
             * We can use an RGB image without any further options since we
             * supplied an RGB output intent profile.
             */
            image = p.load_image("auto", imagefileRGB, "");
            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.fit_image(image, 100, 550, "scale=0.5");
            p.close_image(image);

            /*
             * Similarly, we can use a grayscale image without any further
             * options since we supplied an RGB output intent profile.
             */
            image = p.load_image("auto", imagefileGray, "");
            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.fit_image(image, 100, 250, "scale=0.5");
            p.close_image(image);

            /* For CMYK images we explicitly assign a CMYK ICC profile */
            image = p.load_image("auto", imagefileCMYK, "iccprofile=" + icc);
            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.fit_image(image, 100, 80, "");
            p.close_image(image);

            p.end_page_ext("");

            p.end_document("");
        }
        catch (PDFlibException e) {
            System.err.println("PDFlib exception occurred:");
            System.err.println("[" + e.get_errnum() + "] " + e.get_apiname() +
                ": " + e.get_errmsg());
            exitcode = 1;
        }
        catch (Exception e) {
            System.err.println(e);
            exitcode = 1;
        }
        finally {
            if (p != null) {
                p.delete();
            }
            System.exit(exitcode);
        }
    }
}
