/*
 * PDF/X-3 starter:
 * Create PDF/X-3 conforming output
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 9
 * Required data: font file, image file, ICC profile
 *                (see www.pdflib.com for output intent ICC profiles)
 */
package com.pdflib.cookbook.pdflib.pdfx;

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class starter_pdfx3 {
    public static void main(String argv[]) {
        /* This is where the data files are. Adjust as necessary. */
        String searchpath = "../input";

        pdflib p = null;
        String imagefile = "nesrin.jpg";

        int font, image, spot, icc;
        int exitcode = 0;

        try {
            p = new pdflib();

            p.set_option("searchpath={" + searchpath + "}");

            /* This means we must check return values of load_font() etc. */
            p.set_option("errorpolicy=return");

            if (p.begin_document("starter_pdfx3.pdf", "pdfx=PDF/X-3:2003") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.set_info("Creator", "PDFlib starter sample");
            p.set_info("Title", "starter_pdfx3");

            /* Load output intent ICC profile */
            if (p.load_iccprofile("ISOcoated_v2_eci.icc", "usage=outputintent") == -1) {
                System.err.println("Error: " + p.get_errmsg());
                System.err.println("See www.pdflib.com for output intent ICC profiles.");
                p.delete();
                System.exit(2);
            }

            p.begin_page_ext(0, 0, "width=a4.width height=a4.height");

            /* Font embedding is required for PDF/X */
            font = p.load_font("NotoSerif-Regular", "unicode", "embedding");

            if (font == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.setfont(font, 24);

            spot = p.makespotcolor("PANTONE 123 C");
            p.setcolor("fill", "spot", spot, 1.0, 0.0, 0.0);
            p.fit_textline("PDF/X-3:2003 starter", 50, 700, "");

            /* The RGB image below needs an ICC profile; we use sRGB. */
            icc = p.load_iccprofile("sRGB", "");
            image = p.load_image("auto", imagefile, "iccprofile=" + icc);

            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.fit_image(image, 0.0, 0.0, "scale=0.5");

            p.end_page_ext("");

            p.end_document("");

        }
        catch (PDFlibException e) {
            System.err.println("PDFlib exception occurred:");
            System.err.println("[" + e.get_errnum() + "] " + e.get_apiname() +
                ": " + e.get_errmsg());
            exitcode = 1;
        }
        catch (Exception e) {
            System.err.println(e);
            exitcode = 1;
        }
        finally {
            if (p != null) {
                p.delete();
            }
            System.exit(exitcode);
        }
    }
}
